@@ -1,5 +1,7 @@
 /*
  * Copyright (C) 2009, Pino Toscano <pino@kde.org>
+ * Copyright (C) 2015, Tamas Szekeres <szekerest@gmail.com>
+ * Copyright (C) 2018, Adam Reichold <adam.reichold@t-online.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +24,8 @@
 
 #include "FontInfo.h"
 
+#include <algorithm>
+
 using namespace poppler;
 
 class poppler::font_info_private
@@ -218,7 +222,7 @@ std::vector<font_info> font_iterator::next()
     for (int i = 0; i < items->getLength(); ++i) {
         fonts[i] = font_info(*new font_info_private((FontInfo *)items->get(i)));
     }
-    deleteGooList(items, FontInfo);
+    deleteGooList<FontInfo>(items);
     return fonts;
 }
 
