@@ -16,13 +16,14 @@
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2007 Koji Otani <sho@bbr.jp>
 // Copyright (C) 2007 Carlos Garcia Campos <carlosgc@gnome.org>
-// Copyright (C) 2008, 2009, 2012, 2014-2017 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2009, 2012, 2014-2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008 Tomas Are Haavet <tomasare@gmail.com>
 // Copyright (C) 2012 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
 // Copyright (C) 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2014 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2015 Aleksei Volkov <Aleksei Volkov>
 // Copyright (C) 2015, 2016 William Bader <williambader@hotmail.com>
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -31,10 +32,6 @@
 
 #include <config.h>
 
-#ifdef USE_GCC_PRAGMAS
-#pragma implementation
-#endif
-
 #include <stdlib.h>
 #include <string.h>
 #include <limits.h>
@@ -43,7 +40,6 @@
 #include "goo/gmem.h"
 #include "goo/GooLikely.h"
 #include "goo/GooString.h"
-#include "goo/GooHash.h"
 #include "FoFiType1C.h"
 #include "FoFiTrueType.h"
 #include "poppler/Error.h"
@@ -170,24 +166,24 @@ struct cmpTrueTypeTableTagFunctor {
 
 struct T42Table {
   const char *tag;		// 4-byte tag
-  GBool required;		// required by the TrueType spec?
+  bool required;		// required by the TrueType spec?
 };
 
 // TrueType tables to be embedded in Type 42 fonts.
 // NB: the table names must be in alphabetical order here.
 #define nT42Tables 11
 static T42Table t42Tables[nT42Tables] = {
-  { "cvt ", gTrue  },
-  { "fpgm", gTrue  },
-  { "glyf", gTrue  },
-  { "head", gTrue  },
-  { "hhea", gTrue  },
-  { "hmtx", gTrue  },
-  { "loca", gTrue  },
-  { "maxp", gTrue  },
-  { "prep", gTrue  },
-  { "vhea", gFalse },
-  { "vmtx", gFalse }
+  { "cvt ", true  },
+  { "fpgm", true  },
+  { "glyf", true  },
+  { "head", true  },
+  { "hhea", true  },
+  { "hmtx", true  },
+  { "loca", true  },
+  { "maxp", true  },
+  { "prep", true  },
+  { "vhea", false },
+  { "vmtx", false }
 };
 #define t42HeadTable  3
 #define t42LocaTable  6
@@ -271,42 +267,41 @@ static const char *macGlyphNames[258] = {
 // FoFiTrueType
 //------------------------------------------------------------------------
 
-FoFiTrueType *FoFiTrueType::make(char *fileA, int lenA, int faceIndexA) {
+FoFiTrueType *FoFiTrueType::make(const char *fileA, int lenA, int faceIndexA) {
   FoFiTrueType *ff;
 
-  ff = new FoFiTrueType(fileA, lenA, gFalse, faceIndexA);
+  ff = new FoFiTrueType(fileA, lenA, false, faceIndexA);
   if (!ff->parsedOk) {
     delete ff;
-    return NULL;
+    return nullptr;
   }
   return ff;
 }
 
-FoFiTrueType *FoFiTrueType::load(char *fileName, int faceIndexA) {
+FoFiTrueType *FoFiTrueType::load(const char *fileName, int faceIndexA) {
   FoFiTrueType *ff;
   char *fileA;
   int lenA;
 
   if (!(fileA = FoFiBase::readFile(fileName, &lenA))) {
-    return NULL;
+    return nullptr;
   }
-  ff = new FoFiTrueType(fileA, lenA, gTrue, faceIndexA);
+  ff = new FoFiTrueType(fileA, lenA, true, faceIndexA);
   if (!ff->parsedOk) {
     delete ff;
-    return NULL;
+    return nullptr;
   }
   return ff;
 }
 
-FoFiTrueType::FoFiTrueType(char *fileA, int lenA, GBool freeFileDataA, int faceIndexA):
+FoFiTrueType::FoFiTrueType(const char *fileA, int lenA, bool freeFileDataA, int faceIndexA):
   FoFiBase(fileA, lenA, freeFileDataA)
 {
-  tables = NULL;
+  tables = nullptr;
   nTables = 0;
-  cmaps = NULL;
+  cmaps = nullptr;
   nCmaps = 0;
-  nameToGID = NULL;
-  parsedOk = gFalse;
+  parsedOk = false;
   faceIndex = faceIndexA;
   gsubFeatureTable = 0;
   gsubLookupList = 0;
@@ -317,24 +312,21 @@ FoFiTrueType::FoFiTrueType(char *fileA, int lenA, GBool freeFileDataA, int faceI
 FoFiTrueType::~FoFiTrueType() {
   gfree(tables);
   gfree(cmaps);
-  if (nameToGID) {
-    delete nameToGID;
-  }
 }
 
-int FoFiTrueType::getNumCmaps() {
+int FoFiTrueType::getNumCmaps() const {
   return nCmaps;
 }
 
-int FoFiTrueType::getCmapPlatform(int i) {
+int FoFiTrueType::getCmapPlatform(int i) const {
   return cmaps[i].platform;
 }
 
-int FoFiTrueType::getCmapEncoding(int i) {
+int FoFiTrueType::getCmapEncoding(int i) const {
   return cmaps[i].encoding;
 }
 
-int FoFiTrueType::findCmap(int platform, int encoding) {
+int FoFiTrueType::findCmap(int platform, int encoding) const {
   int i;
 
   for (i = 0; i < nCmaps; ++i) {
@@ -345,17 +337,17 @@ int FoFiTrueType::findCmap(int platform, int encoding) {
   return -1;
 }
 
-int FoFiTrueType::mapCodeToGID(int i, Guint c) {
+int FoFiTrueType::mapCodeToGID(int i, Guint c) const {
   int gid;
   Guint segCnt, segEnd, segStart, segDelta, segOffset;
   Guint cmapFirst, cmapLen;
   int pos, a, b, m;
-  GBool ok;
+  bool ok;
 
   if (i < 0 || i >= nCmaps) {
     return 0;
   }
-  ok = gTrue;
+  ok = true;
   pos = cmaps[i].offset;
   switch (cmaps[i].fmt) {
   case 0:
@@ -442,29 +434,30 @@ int FoFiTrueType::mapCodeToGID(int i, Guint c) {
   return gid;
 }
 
-int FoFiTrueType::mapNameToGID(char *name) {
-  if (!nameToGID) {
+int FoFiTrueType::mapNameToGID(const char *name) const {
+  const auto gid = nameToGID.find(name);
+  if (gid == nameToGID.end()) {
     return 0;
   }
-  return nameToGID->lookupInt(name);
+  return gid->second;
 }
 
-GBool FoFiTrueType::getCFFBlock(char **start, int *length) {
+bool FoFiTrueType::getCFFBlock(char **start, int *length) const {
   int i;
 
   if (!openTypeCFF || !tables) {
-    return gFalse;
+    return false;
   }
   i = seekTable("CFF ");
   if (!checkRegion(tables[i].offset, tables[i].len)) {
-    return gFalse;
+    return false;
   }
   *start = (char *)file + tables[i].offset;
   *length = tables[i].len;
-  return gTrue;
+  return true;
 }
 
-int *FoFiTrueType::getCIDToGIDMap(int *nCIDs) {
+int *FoFiTrueType::getCIDToGIDMap(int *nCIDs) const {
   char *start;
   int length;
   FoFiType1C *ff;
@@ -472,24 +465,24 @@ int *FoFiTrueType::getCIDToGIDMap(int *nCIDs) {
 
   *nCIDs = 0;
   if (!getCFFBlock(&start, &length)) {
-    return NULL;
+    return nullptr;
   }
   if (!(ff = FoFiType1C::make(start, length))) {
-    return NULL;
+    return nullptr;
   }
   map = ff->getCIDToGIDMap(nCIDs);
   delete ff;
   return map;
 }
 
-int FoFiTrueType::getEmbeddingRights() {
+int FoFiTrueType::getEmbeddingRights() const {
   int i, fsType;
-  GBool ok;
+  bool ok;
 
   if ((i = seekTable("OS/2")) < 0) {
     return 4;
   }
-  ok = gTrue;
+  ok = true;
   fsType = getU16BE(tables[i].offset + 8, &ok);
   if (!ok) {
     return 4;
@@ -506,7 +499,7 @@ int FoFiTrueType::getEmbeddingRights() {
   return 3;
 }
 
-void FoFiTrueType::getFontMatrix(double *mat) {
+void FoFiTrueType::getFontMatrix(double *mat) const {
   char *start;
   int length;
   FoFiType1C *ff;
@@ -521,20 +514,20 @@ void FoFiTrueType::getFontMatrix(double *mat) {
   delete ff;
 }
 
-void FoFiTrueType::convertToType42(char *psName, char **encoding,
+void FoFiTrueType::convertToType42(const char *psName, char **encoding,
 				   int *codeToGID,
 				   FoFiOutputFunc outputFunc,
-				   void *outputStream) {
+				   void *outputStream) const {
   GooString *buf;
   int maxUsedGlyph;
-  GBool ok;
+  bool ok;
 
   if (openTypeCFF) {
     return;
   }
 
   // write the header
-  ok = gTrue;
+  ok = true;
   buf = GooString::format("%!PS-TrueTypeFont-{0:2g}\n",
 			(double)getS32BE(0, &ok) / 65536.0);
   (*outputFunc)(outputStream, buf->getCString(), buf->getLength());
@@ -556,15 +549,15 @@ void FoFiTrueType::convertToType42(char *psName, char **encoding,
   // write the guts of the dictionary
   cvtEncoding(encoding, outputFunc, outputStream);
   cvtCharStrings(encoding, codeToGID, outputFunc, outputStream);
-  cvtSfnts(outputFunc, outputStream, NULL, gFalse, &maxUsedGlyph);
+  cvtSfnts(outputFunc, outputStream, nullptr, false, &maxUsedGlyph);
 
   // end the dictionary and define the font
   (*outputFunc)(outputStream, "FontName currentdict end definefont pop\n", 40);
 }
 
-void FoFiTrueType::convertToType1(char *psName, const char **newEncoding,
-				  GBool ascii, FoFiOutputFunc outputFunc,
-				  void *outputStream) {
+void FoFiTrueType::convertToType1(const char *psName, const char **newEncoding,
+				  bool ascii, FoFiOutputFunc outputFunc,
+				  void *outputStream) const {
   char *start;
   int length;
   FoFiType1C *ff;
@@ -579,14 +572,14 @@ void FoFiTrueType::convertToType1(char *psName, const char **newEncoding,
   delete ff;
 }
 
-void FoFiTrueType::convertToCIDType2(char *psName,
+void FoFiTrueType::convertToCIDType2(const char *psName,
 				     int *cidMap, int nCIDs,
-				     GBool needVerticalMetrics,
+				     bool needVerticalMetrics,
 				     FoFiOutputFunc outputFunc,
-				     void *outputStream) {
+				     void *outputStream) const {
   GooString *buf;
   int cid, maxUsedGlyph;
-  GBool ok;
+  bool ok;
   int i, j, k;
 
   if (openTypeCFF) {
@@ -594,7 +587,7 @@ void FoFiTrueType::convertToCIDType2(char *psName,
   }
 
   // write the header
-  ok = gTrue;
+  ok = true;
   buf = GooString::format("%!PS-TrueTypeFont-{0:2g}\n",
 			(double)getS32BE(0, &ok) / 65536.0);
   (*outputFunc)(outputStream, buf->getCString(), buf->getLength());
@@ -701,7 +694,7 @@ void FoFiTrueType::convertToCIDType2(char *psName,
   (*outputFunc)(outputStream, "  end readonly def\n", 19);
 
   // write the guts of the dictionary
-  cvtSfnts(outputFunc, outputStream, NULL, needVerticalMetrics, &maxUsedGlyph);
+  cvtSfnts(outputFunc, outputStream, nullptr, needVerticalMetrics, &maxUsedGlyph);
 
   // end the dictionary and define the font
   (*outputFunc)(outputStream,
@@ -709,9 +702,9 @@ void FoFiTrueType::convertToCIDType2(char *psName,
 		56);
 }
 
-void FoFiTrueType::convertToCIDType0(char *psName, int *cidMap, int nCIDs,
+void FoFiTrueType::convertToCIDType0(const char *psName, int *cidMap, int nCIDs,
 				     FoFiOutputFunc outputFunc,
-				     void *outputStream) {
+				     void *outputStream) const {
   char *start;
   int length;
   FoFiType1C *ff;
@@ -726,11 +719,11 @@ void FoFiTrueType::convertToCIDType0(char *psName, int *cidMap, int nCIDs,
   delete ff;
 }
 
-void FoFiTrueType::convertToType0(char *psName, int *cidMap, int nCIDs,
-				  GBool needVerticalMetrics,
+void FoFiTrueType::convertToType0(const char *psName, int *cidMap, int nCIDs,
+				  bool needVerticalMetrics,
 				  int *maxValidGlyph,
 				  FoFiOutputFunc outputFunc,
-				  void *outputStream) {
+				  void *outputStream) const {
   GooString *buf;
   GooString *sfntsName;
   int maxUsedGlyph, n, i, j;
@@ -841,9 +834,9 @@ void FoFiTrueType::convertToType0(char *psName, int *cidMap, int nCIDs,
   (*outputFunc)(outputStream, "FontName currentdict end definefont pop\n", 40);
 }
 
-void FoFiTrueType::convertToType0(char *psName, int *cidMap, int nCIDs,
+void FoFiTrueType::convertToType0(const char *psName, int *cidMap, int nCIDs,
 				  FoFiOutputFunc outputFunc,
-				  void *outputStream) {
+				  void *outputStream) const {
   char *start;
   int length;
   FoFiType1C *ff;
@@ -860,7 +853,7 @@ void FoFiTrueType::convertToType0(char *psName, int *cidMap, int nCIDs,
 
 void FoFiTrueType::cvtEncoding(char **encoding,
 			       FoFiOutputFunc outputFunc,
-			       void *outputStream) {
+			       void *outputStream) const {
   const char *name;
   GooString *buf;
   int i;
@@ -890,8 +883,8 @@ void FoFiTrueType::cvtEncoding(char **encoding,
 void FoFiTrueType::cvtCharStrings(char **encoding,
 				  int *codeToGID,
 				  FoFiOutputFunc outputFunc,
-				  void *outputStream) {
-  char *name;
+				  void *outputStream) const {
+  const char *name;
   GooString *buf;
   char buf2[16];
   int i, k;
@@ -941,14 +934,14 @@ void FoFiTrueType::cvtCharStrings(char **encoding,
 
 void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc,
 			    void *outputStream, GooString *name,
-			    GBool needVerticalMetrics,
-                            int *maxUsedGlyph) {
+			    bool needVerticalMetrics,
+                            int *maxUsedGlyph) const {
   Guchar headData[54];
   TrueTypeLoca *locaTable;
   Guchar *locaData;
   TrueTypeTable newTables[nT42Tables];
   Guchar tableDir[12 + nT42Tables*16];
-  GBool ok;
+  bool ok;
   Guint checksum;
   int nNewTables;
   int glyfTableLen, length, pos, glyfPos, i, j, k, vmtxTabLength;
@@ -972,7 +965,7 @@ void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc,
     0, 1			// number of advance heights in vmtx table
   };
   Guchar *vmtxTab;
-  GBool needVhea, needVmtx;
+  bool needVhea, needVmtx;
   int advance;
 
   // construct the 'head' table, zero out the font checksum
@@ -1006,7 +999,7 @@ void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc,
   pos = tables[i].offset;
   i = seekTable("glyf");
   glyfTableLen = tables[i].len;
-  ok = gTrue;
+  ok = true;
   for (i = 0; i <= nGlyphs; ++i) {
     locaTable[i].idx = i;
     if (locaFmt) {
@@ -1061,7 +1054,7 @@ void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc,
       ++nNewTables;
     }
   }
-  vmtxTab = NULL; // make gcc happy
+  vmtxTab = nullptr; // make gcc happy
   vmtxTabLength = 0;
   advance = 0; // make gcc happy
   if (needVerticalMetrics) {
@@ -1261,9 +1254,9 @@ void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc,
   }
 }
 
-void FoFiTrueType::dumpString(Guchar *s, int length,
+void FoFiTrueType::dumpString(const Guchar *s, int length,
 			      FoFiOutputFunc outputFunc,
-			      void *outputStream) {
+			      void *outputStream) const {
   GooString *buf;
   int pad, i, j;
 
@@ -1290,7 +1283,7 @@ void FoFiTrueType::dumpString(Guchar *s, int length,
   (*outputFunc)(outputStream, "00>\n", 4);
 }
 
-Guint FoFiTrueType::computeTableChecksum(Guchar *data, int length) {
+Guint FoFiTrueType::computeTableChecksum(const Guchar *data, int length) const {
   Guint checksum, word;
   int i;
 
@@ -1325,7 +1318,7 @@ void FoFiTrueType::parse() {
   Guint topTag;
   int pos, ver, i, j;
 
-  parsedOk = gTrue;
+  parsedOk = true;
 
   // look for a collection (TTC)
   topTag = getU32BE(0, &parsedOk);
@@ -1340,7 +1333,7 @@ void FoFiTrueType::parse() {
     if (!parsedOk)
       return;
     if (! dircount) {
-      parsedOk = gFalse;
+      parsedOk = false;
       return;
     }
 
@@ -1387,7 +1380,7 @@ void FoFiTrueType::parse() {
     nTables = j;
     tables = (TrueTypeTable *)greallocn_checkoverflow(tables, nTables, sizeof(TrueTypeTable));
   }
-  if (!parsedOk || tables == NULL) {
+  if (!parsedOk || tables == nullptr) {
     return;
   }
 
@@ -1399,7 +1392,7 @@ void FoFiTrueType::parse() {
       (!openTypeCFF && seekTable("loca") < 0) ||
       (!openTypeCFF && seekTable("glyf") < 0) ||
       (openTypeCFF && seekTable("CFF ") < 0)) {
-    parsedOk = gFalse;
+    parsedOk = false;
     return;
   }
 
@@ -1450,12 +1443,12 @@ void FoFiTrueType::parse() {
 }
 
 void FoFiTrueType::readPostTable() {
-  GooString *name;
-  int tablePos, postFmt, stringIdx, stringPos, savedStringIdx;
-  GBool ok;
+  std::string name;
+  int tablePos, postFmt, stringIdx, stringPos;
+  bool ok;
   int i, j, n, m;
 
-  ok = gTrue;
+  ok = true;
   if ((i = seekTable("post")) < 0) {
     return;
   }
@@ -1465,12 +1458,12 @@ void FoFiTrueType::readPostTable() {
     goto err;
   }
   if (postFmt == 0x00010000) {
-    nameToGID = new GooHash(gTrue);
+    nameToGID.reserve(258);
     for (i = 0; i < 258; ++i) {
-      nameToGID->add(new GooString(macGlyphNames[i]), i);
+      nameToGID.emplace(macGlyphNames[i], i);
     }
   } else if (postFmt == 0x00020000) {
-    nameToGID = new GooHash(gTrue);
+    nameToGID.reserve(258);
     n = getU16BE(tablePos + 32, &ok);
     if (!ok) {
       goto err;
@@ -1481,50 +1474,39 @@ void FoFiTrueType::readPostTable() {
     stringIdx = 0;
     stringPos = tablePos + 34 + 2*n;
     for (i = 0; i < n; ++i) {
+      ok = true;
       j = getU16BE(tablePos + 34 + 2*i, &ok);
       if (j < 258) {
-	nameToGID->removeInt(macGlyphNames[j]);
-	nameToGID->add(new GooString(macGlyphNames[j]), i);
+	nameToGID[macGlyphNames[j]] = i;
       } else {
-	savedStringIdx = stringIdx;
 	j -= 258;
 	if (j != stringIdx) {
 	  for (stringIdx = 0, stringPos = tablePos + 34 + 2*n;
 	       stringIdx < j;
 	       ++stringIdx, stringPos += 1 + getU8(stringPos, &ok)) ;
 	  if (!ok) {
-	    goto err;
+	    continue;
 	  }
 	}
 	m = getU8(stringPos, &ok);
 	if (!ok || !checkRegion(stringPos + 1, m)) {
-	  stringIdx = savedStringIdx;
-	  if (j < 258) {
-	    ok = gTrue;
-	    nameToGID->removeInt(macGlyphNames[j]);
-	    nameToGID->add(new GooString(macGlyphNames[0]), i);
-	  } else {
-	    goto err;
-	  }
-	} else {
-	  name = new GooString((char *)&file[stringPos + 1], m);
-	  nameToGID->removeInt(name);
-	  nameToGID->add(name, i);
-	  ++stringIdx;
-	  stringPos += 1 + m;
-        }
+	  continue;
+	}
+	name.assign((char *)&file[stringPos + 1], m);
+	nameToGID[name] = i;
+	++stringIdx;
+	stringPos += 1 + m;
       }
     }
   } else if (postFmt == 0x00028000) {
-    nameToGID = new GooHash(gTrue);
+    nameToGID.reserve(258);
     for (i = 0; i < nGlyphs; ++i) {
       j = getU8(tablePos + 32 + i, &ok);
       if (!ok) {
-	goto err;
+	continue;
       }
       if (j < 258) {
-	nameToGID->removeInt(macGlyphNames[j]);
-	nameToGID->add(new GooString(macGlyphNames[j]), i);
+	nameToGID[macGlyphNames[j]] = i;
       }
     }
   }
@@ -1532,13 +1514,10 @@ void FoFiTrueType::readPostTable() {
   return;
 
  err:
-  if (nameToGID) {
-    delete nameToGID;
-    nameToGID = NULL;
-  }
+  nameToGID.clear();
 }
 
-int FoFiTrueType::seekTable(const char *tag) {
+int FoFiTrueType::seekTable(const char *tag) const {
   Guint tagI;
   int i;
 
@@ -1578,7 +1557,7 @@ Guint FoFiTrueType::charToTag(const char *tagName)
 */
 int FoFiTrueType::setupGSUB(const char *scriptName)
 {
-  return setupGSUB(scriptName, NULL);
+  return setupGSUB(scriptName, nullptr);
 }
 
 /*
@@ -1603,7 +1582,7 @@ int FoFiTrueType::setupGSUB(const char *scriptName,
   int x;
   Guint pos;
 
-  if (scriptName == 0) {
+  if (scriptName == nullptr) {
     gsubFeatureTable = 0;
     return 0;
   }
