@@ -21,8 +21,11 @@
 
 #include <glib-object.h>
 
+#include "poppler-macros.h"
+
 G_BEGIN_DECLS
 
+POPPLER_PUBLIC
 GQuark poppler_error_quark (void);
 
 #define POPPLER_ERROR poppler_error_quark ()
@@ -46,14 +49,6 @@ typedef enum
   POPPLER_ERROR_DAMAGED
 } PopplerError;
 
-typedef enum
-{
-  POPPLER_ORIENTATION_PORTRAIT,
-  POPPLER_ORIENTATION_LANDSCAPE,
-  POPPLER_ORIENTATION_UPSIDEDOWN,
-  POPPLER_ORIENTATION_SEASCAPE
-} PopplerOrientation;
-
 /**
  * PopplerPageTransitionType:
  * @POPPLER_PAGE_TRANSITION_REPLACE: the new page replace the old one
@@ -228,7 +223,9 @@ typedef enum
   POPPLER_BACKEND_CAIRO
 } PopplerBackend;
 
+POPPLER_PUBLIC
 PopplerBackend poppler_get_backend (void);
+POPPLER_PUBLIC
 const char *   poppler_get_version (void);
 
 G_END_DECLS
