@@ -17,6 +17,7 @@
 // Copyright (C) 2008, 2009, 2017, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2013 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -25,10 +26,6 @@
 
 #include <config.h>
 
-#ifdef USE_GCC_PRAGMAS
-#pragma implementation
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -45,7 +42,7 @@
 //------------------------------------------------------------------------
 
 struct CMapVectorEntry {
-  GBool isVector;
+  bool isVector;
   union {
     CMapVectorEntry *vector;
     CID cid;
@@ -64,7 +61,7 @@ static int getCharFromStream(void *data) {
 
 //------------------------------------------------------------------------
 
-CMap *CMap::parse(CMapCache *cache, GooString *collectionA, Object *obj) {
+CMap *CMap::parse(CMapCache *cache, const GooString *collectionA, Object *obj) {
   CMap *cMap;
   GooString *cMapNameA;
 
@@ -87,8 +84,8 @@ CMap *CMap::parse(CMapCache *cache, GooString *collectionA, Object *obj) {
   return cMap;
 }
 
-CMap *CMap::parse(CMapCache *cache, GooString *collectionA,
-		  GooString *cMapNameA) {
+CMap *CMap::parse(CMapCache *cache, const GooString *collectionA,
+		  const GooString *cMapNameA) {
   FILE *f;
   CMap *cMap;
 
@@ -116,7 +113,7 @@ CMap *CMap::parse(CMapCache *cache, GooString *collectionA,
   return cMap;
 }
 
-CMap *CMap::parse(CMapCache *cache, GooString *collectionA, Stream *str) {
+CMap *CMap::parse(CMapCache *cache, const GooString *collectionA, Stream *str) {
   CMap *cMap = new CMap(collectionA->copy(), nullptr);
   Object obj1 = str->getDict()->lookup("UseCMap");
   if (!obj1.isNull()) {
@@ -129,8 +126,8 @@ CMap *CMap::parse(CMapCache *cache, GooString *collectionA, Stream *str) {
   return cMap;
 }
 
-CMap *CMap::parse(CMapCache *cache, GooString *collectionA,
-		  GooString *cMapNameA, Stream *stream) {
+CMap *CMap::parse(CMapCache *cache, const GooString *collectionA,
+		  const GooString *cMapNameA, Stream *stream) {
   FILE *f = nullptr;
   CMap *cmap;
   PSTokenizer *pst;
@@ -234,7 +231,7 @@ void CMap::parse2(CMapCache *cache, int (*getCharFunc)(void *), void *data) {
   PSTokenizer *pst;
   char tok1[256], tok2[256], tok3[256];
   int n1, n2, n3;
-  Guint start, end, code;
+  Guint start = 0, end = 0, code;
 
   pst = new PSTokenizer(getCharFunc, data);
   pst->getToken(tok1, sizeof(tok1), &n1);
@@ -305,29 +302,23 @@ CMap::CMap(GooString *collectionA, GooString *cMapNameA) {
 
   collection = collectionA;
   cMapName = cMapNameA;
-  isIdent = gFalse;
+  isIdent = false;
   wMode = 0;
   vector = (CMapVectorEntry *)gmallocn(256, sizeof(CMapVectorEntry));
   for (i = 0; i < 256; ++i) {
-    vector[i].isVector = gFalse;
+    vector[i].isVector = false;
     vector[i].cid = 0;
   }
   refCnt = 1;
-#ifdef MULTITHREADED
-  gInitMutex(&mutex);
-#endif
 }
 
 CMap::CMap(GooString *collectionA, GooString *cMapNameA, int wModeA) {
   collection = collectionA;
   cMapName = cMapNameA;
-  isIdent = gTrue;
+  isIdent = true;
   wMode = wModeA;
   vector = nullptr;
   refCnt = 1;
-#ifdef MULTITHREADED
-  gInitMutex(&mutex);
-#endif
 }
 
 void CMap::useCMap(CMapCache *cache, char *useName) {
@@ -375,11 +366,11 @@ void CMap::copyVector(CMapVectorEntry *dest, CMapVectorEntry *src) {
   for (i = 0; i < 256; ++i) {
     if (src[i].isVector) {
       if (!dest[i].isVector) {
-	dest[i].isVector = gTrue;
+	dest[i].isVector = true;
 	dest[i].vector =
 	  (CMapVectorEntry *)gmallocn(256, sizeof(CMapVectorEntry));
 	for (j = 0; j < 256; ++j) {
-	  dest[i].vector[j].isVector = gFalse;
+	  dest[i].vector[j].isVector = false;
 	  dest[i].vector[j].cid = 0;
 	}
       }
@@ -404,11 +395,11 @@ void CMap::addCIDs(Guint start, Guint end, Guint nBytes, CID firstCID) {
   for (i = nBytes - 1; i >= 1; --i) {
     byte = (start >> (8 * i)) & 0xff;
     if (!vec[byte].isVector) {
-      vec[byte].isVector = gTrue;
+      vec[byte].isVector = true;
       vec[byte].vector =
 	  (CMapVectorEntry *)gmallocn(256, sizeof(CMapVectorEntry));
       for (j = 0; j < 256; ++j) {
-	vec[byte].vector[j].isVector = gFalse;
+	vec[byte].vector[j].isVector = false;
 	vec[byte].vector[j].cid = 0;
       }
     }
@@ -433,9 +424,6 @@ CMap::~CMap() {
   if (vector) {
     freeCMapVector(vector);
   }
-#ifdef MULTITHREADED
-  gDestroyMutex(&mutex);
-#endif
 }
 
 void CMap::freeCMapVector(CMapVectorEntry *vec) {
@@ -450,31 +438,16 @@ void CMap::freeCMapVector(CMapVectorEntry *vec) {
 }
 
 void CMap::incRefCnt() {
-#ifdef MULTITHREADED
-  gLockMutex(&mutex);
-#endif
   ++refCnt;
-#ifdef MULTITHREADED
-  gUnlockMutex(&mutex);
-#endif
 }
 
 void CMap::decRefCnt() {
-  GBool done;
-
-#ifdef MULTITHREADED
-  gLockMutex(&mutex);
-#endif
-  done = --refCnt == 0;
-#ifdef MULTITHREADED
-  gUnlockMutex(&mutex);
-#endif
-  if (done) {
+  if (--refCnt == 0) {
     delete this;
   }
 }
 
-GBool CMap::match(GooString *collectionA, GooString *cMapNameA) {
+bool CMap::match(const GooString *collectionA, const GooString *cMapNameA) {
   return !collection->cmp(collectionA) && !cMapName->cmp(cMapNameA);
 }
 
@@ -561,7 +534,7 @@ CMapCache::~CMapCache() {
   }
 }
 
-CMap *CMapCache::getCMap(GooString *collection, GooString *cMapName, Stream *stream) {
+CMap *CMapCache::getCMap(const GooString *collection, const GooString *cMapName, Stream *stream) {
   CMap *cmap;
   int i, j;
 
