@@ -37,15 +37,11 @@
 #ifndef CATALOG_H
 #define CATALOG_H
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
-
 #include "poppler-config.h"
 #include "Object.h"
-#include "goo/GooMutex.h"
 
 #include <vector>
+#include <memory>
 
 class PDFDoc;
 class XRef;
@@ -120,7 +116,7 @@ public:
   Catalog& operator=(const Catalog &) = delete;
 
   // Is catalog valid?
-  GBool isOk() { return ok; }
+  bool isOk() { return ok; }
 
   // Get number of pages.
   int getNumPages();
@@ -192,8 +188,8 @@ public:
   GooString *getJS(int i);
 
   // Convert between page indices and page labels.
-  GBool labelToIndex(GooString *label, int *index);
-  GBool indexToLabel(int index, GooString *label);
+  bool labelToIndex(GooString *label, int *index);
+  bool indexToLabel(int index, GooString *label);
 
   Object *getOutline();
 
@@ -254,9 +250,7 @@ private:
 
   PDFDoc *doc;
   XRef *xref;			// the xref table for this PDF file
-  Page **pages;			// array of pages
-  Ref *pageRefs;		// object ID for each page
-  int lastCachedPage;
+  std::vector<std::pair<std::unique_ptr<Page>, Ref>> pages;
   std::vector<Object> *pagesList;
   std::vector<Ref> *pagesRefList;
   std::vector<PageAttrs *> *attrsList;
@@ -264,7 +258,6 @@ private:
   Form *form;
   ViewerPreferences *viewerPrefs;
   int numPages;			// number of pages
-  int pagesSize;		// size of pages array
   Object dests;			// named destination dictionary
   Object names;			// named names dictionary
   NameTree *destNameTree;	// named destination name-tree
@@ -278,13 +271,13 @@ private:
   Object acroForm;		// AcroForm dictionary
   Object viewerPreferences;     // ViewerPreference dictionary
   OCGs *optContent;		// Optional Content groups
-  GBool ok;			// true if catalog is valid
+  bool ok;			// true if catalog is valid
   PageLabelInfo *pageLabelInfo; // info about page labels
   PageMode pageMode;		// page mode
   PageLayout pageLayout;	// page layout
   Object additionalActions;     // page additional actions
 
-  GBool cachePageTree(int page); // Cache first <page> pages.
+  bool cachePageTree(int page); // Cache first <page> pages.
   Object *findDestInTree(Object *tree, GooString *name, Object *obj);
 
   Object *getNames();
@@ -292,10 +285,8 @@ private:
   NameTree *getEmbeddedFileNameTree();
   NameTree *getJSNameTree();
   LinkDest *createLinkDest(Object *obj);
-#ifdef MULTITHREADED
-  GooMutex mutex;
-#endif
 
+  mutable std::recursive_mutex mutex;
 };
 
 #endif
