@@ -24,10 +24,6 @@
 #ifndef FORM_H
 #define FORM_H
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
-
 #include "goo/GooList.h"
 #include "Object.h"
 #include "Annot.h"
@@ -93,7 +89,7 @@ public:
   virtual ~FormWidget();
 
   // Check if point is inside the field bounding rect
-  GBool inRect(double x, double y) const;
+  bool inRect(double x, double y) const;
 
   // Get the field bounding rect
   void getRect(double *x1, double *y1, double *x2, double *y2) const;
@@ -116,7 +112,7 @@ public:
   const GooString *getMappingName() const;
   GooString *getFullyQualifiedName();
 
-  GBool isModified () const;
+  bool isModified () const;
 
   bool isReadOnly() const;
   void setReadOnly(bool value);
@@ -134,9 +130,7 @@ public:
 
   virtual void updateWidgetAppearance() = 0;
 
-#ifdef DEBUG_FORMS
   void print(int indent = 0);
-#endif
 
 protected:
   FormWidget(PDFDoc *docA, Object *aobj, unsigned num, Ref aref, FormField *fieldA);
@@ -174,10 +168,10 @@ public:
 
   FormButtonType getButtonType() const;
   
-  void setState (GBool state);
-  GBool getState ();
+  void setState (bool state);
+  bool getState () const;
 
-  char* getOnStr();
+  const char* getOnStr() const;
   void setAppearanceState(const char *state);
   void updateWidgetAppearance() override;
 
@@ -306,7 +300,7 @@ public:
   bool isReadOnly () const { return readOnly; }
 
   GooString* getDefaultAppearance() const { return defaultAppearance; }
-  GBool hasTextQuadding() const { return hasQuadding; }
+  bool hasTextQuadding() const { return hasQuadding; }
   VariableTextQuadding getTextQuadding() const { return quadding; }
 
   const GooString *getPartialName() const { return partialName; }
@@ -317,18 +311,15 @@ public:
 
   FormWidget* findWidgetByRef (Ref aref);
   int getNumWidgets() { return terminal ? numChildren : 0; }
-  FormWidget *getWidget(int i) { return terminal ? widgets[i] : NULL; }
+  FormWidget *getWidget(int i) { return terminal ? widgets[i] : nullptr; }
 
   // only implemented in FormFieldButton
   virtual void fillChildrenSiblingsID ();
 
   void createWidgetAnnotations();
 
-#ifdef DEBUG_FORMS
   void printTree(int indent = 0);
   virtual void print(int indent = 0);
-#endif
-
 
  protected:
   void _createWidget (Object *obj, Ref aref);
@@ -354,7 +345,7 @@ public:
 
   // Variable Text
   GooString *defaultAppearance;
-  GBool hasQuadding;
+  bool hasQuadding;
   VariableTextQuadding quadding;
 
 private:
@@ -374,9 +365,9 @@ public:
 
   bool noToggleToOff () const { return noAllOff; }
 
-  // returns gTrue if the state modification is accepted
-  GBool setState (char *state);
-  GBool getState(const char *state) const;
+  // returns true if the state modification is accepted
+  bool setState (const char *state);
+  bool getState(const char *state) const;
 
   const char *getAppearanceState() const { return appearanceState.isName() ? appearanceState.getName() : nullptr; }
 
@@ -389,13 +380,11 @@ public:
   FormFieldButton* getSibling (int i) const { return siblings[i]; }
   int getNumSiblings () const { return numSiblings; }
 
-#ifdef DEBUG_FORMS
-  void print(int indent = 0);
-#endif
+  void print(int indent) override;
 
   ~FormFieldButton();
 protected:
-  void updateState(char *state);
+  void updateState(const char *state);
 
   FormFieldButton** siblings; // IDs of dependent buttons (each button of a radio field has all the others buttons
                                // of the same field in this array)
@@ -435,9 +424,7 @@ public:
   //set the font size of the field's text (currently only integer values)
   void setTextFontSize(int fontSize);
 
-#ifdef DEBUG_FORMS
-  void print(int indent = 0);
-#endif
+  void print(int indent) override;
 
   static int tokenizeDA(const GooString* daString, GooList* daToks, const char* searchTok);
 
@@ -466,8 +453,8 @@ public:
   ~FormFieldChoice();
 
   int getNumChoices() const { return numChoices; }
-  const GooString* getChoice(int i) const { return choices ? choices[i].optionName : NULL; }
-  const GooString* getExportVal (int i) const  { return choices ? choices[i].exportVal : NULL; }
+  const GooString* getChoice(int i) const { return choices ? choices[i].optionName : nullptr; }
+  const GooString* getExportVal (int i) const  { return choices ? choices[i].exportVal : nullptr; }
   // For multi-select choices it returns the first one
   const GooString* getSelectedChoice() const;
 
@@ -498,9 +485,7 @@ public:
 
   int getTopIndex() const { return topIdx; }
 
-#ifdef DEBUG_FORMS
-  void print(int indent = 0);
-#endif
+  void print(int indent) override;
 
 protected:
   void unselectAll();
@@ -549,9 +534,7 @@ private:
   GooString *signature;
   SignatureInfo *signature_info;
 
-#ifdef DEBUG_FORMS
-  void print(int indent = 0);
-#endif
+  void print(int indent) override;
 };
 
 //------------------------------------------------------------------------
@@ -577,7 +560,7 @@ public:
   static FormField *createFieldFromDict (Object* obj, PDFDoc *docA, const Ref& aref, FormField *parent, std::set<int> *usedParents);
 
   Object *getObj () const { return acroForm; }
-  GBool getNeedAppearances () const { return needAppearances; }
+  bool getNeedAppearances () const { return needAppearances; }
   int getNumFields() const { return numFields; }
   FormField* getRootField(int i) const { return rootFields[i]; }
   const GooString* getDefaultAppearance() const { return defaultAppearance; }
@@ -598,7 +581,7 @@ private:
   PDFDoc *doc;
   XRef* xref;
   Object *acroForm;
-  GBool needAppearances;
+  bool needAppearances;
   GfxResources *defaultResources;
   Object resDict;
   std::vector<Ref> calculateOrder;
