@@ -22,6 +22,7 @@
 // Copyright (C) 2012 Tobias Koening <tobias.koenig@kdab.com>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Intevation GmbH <intevation@intevation.de>
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -30,10 +31,6 @@
 
 #include <config.h>
 
-#ifdef USE_GCC_PRAGMAS
-#pragma implementation
-#endif
-
 #include <stddef.h>
 #include <string.h>
 #include "goo/gmem.h"
@@ -57,7 +54,7 @@ LinkAction::LinkAction() : nextActionList(nullptr) {
 
 LinkAction::~LinkAction() {
   if (nextActionList)
-    deleteGooList(nextActionList, LinkAction);
+    deleteGooList<LinkAction>(nextActionList);
 }
 
 LinkAction *LinkAction::parseDest(const Object *obj) {
@@ -175,12 +172,14 @@ LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI,
         }
     }
 
-    actionList = new GooList(1);
-    actionList->append(parseAction(&nextObj, nullptr, seenNextActions));
+    actionList = new GooList();
+    actionList->reserve(1);
+    actionList->push_back(parseAction(&nextObj, nullptr, seenNextActions));
   } else if (nextObj.isArray()) {
     const Array *a = nextObj.getArray();
     const int n = a->getLength();
-    actionList = new GooList(n);
+    actionList = new GooList();
+    actionList->reserve(n);
     for (int i = 0; i < n; ++i) {
       const Object obj3 = a->get(i);
       if (!obj3.isDict()) {
@@ -198,7 +197,7 @@ LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI,
           }
       }
 
-      actionList->append(parseAction(&obj3, nullptr, seenNextActions));
+      actionList->push_back(parseAction(&obj3, nullptr, seenNextActions));
     }
   }
 
@@ -223,8 +222,8 @@ void LinkAction::setNextActions(GooList *actions) {
 LinkDest::LinkDest(const Array *a) {
   // initialize fields
   left = bottom = right = top = zoom = 0;
-  changeLeft = changeTop = changeZoom = gFalse;
-  ok = gFalse;
+  changeLeft = changeTop = changeZoom = false;
+  ok = false;
 
   // get page
   if (a->getLength() < 2) {
@@ -234,11 +233,11 @@ LinkDest::LinkDest(const Array *a) {
   Object obj1 = a->getNF(0);
   if (obj1.isInt()) {
     pageNum = obj1.getInt() + 1;
-    pageIsRef = gFalse;
+    pageIsRef = false;
   } else if (obj1.isRef()) {
     pageRef.num = obj1.getRefNum();
     pageRef.gen = obj1.getRefGen();
-    pageIsRef = gTrue;
+    pageIsRef = true;
   } else {
     error(errSyntaxWarning, -1, "Bad annotation destination");
     return;
@@ -251,13 +250,13 @@ LinkDest::LinkDest(const Array *a) {
   if (obj1.isName("XYZ")) {
     kind = destXYZ;
     if (a->getLength() < 3) {
-      changeLeft = gFalse;
+      changeLeft = false;
     } else {
       Object obj2 = a->get(2);
       if (obj2.isNull()) {
-	changeLeft = gFalse;
+	changeLeft = false;
       } else if (obj2.isNum()) {
-	changeLeft = gTrue;
+	changeLeft = true;
 	left = obj2.getNum();
       } else {
 	error(errSyntaxWarning, -1, "Bad annotation destination position");
@@ -265,13 +264,13 @@ LinkDest::LinkDest(const Array *a) {
       }
     }
     if (a->getLength() < 4) {
-      changeTop = gFalse;
+      changeTop = false;
     } else {
       Object obj2 = a->get(3);
       if (obj2.isNull()) {
-	changeTop = gFalse;
+	changeTop = false;
       } else if (obj2.isNum()) {
-	changeTop = gTrue;
+	changeTop = true;
 	top = obj2.getNum();
       } else {
 	error(errSyntaxWarning, -1, "Bad annotation destination position");
@@ -279,14 +278,14 @@ LinkDest::LinkDest(const Array *a) {
       }
     }
     if (a->getLength() < 5) {
-      changeZoom = gFalse;
+      changeZoom = false;
     } else {
       Object obj2 = a->get(4);
       if (obj2.isNull()) {
-	changeZoom = gFalse;
+	changeZoom = false;
       } else if (obj2.isNum()) {
 	zoom = obj2.getNum();
-	changeZoom = (zoom == 0) ? gFalse : gTrue;
+	changeZoom = (zoom == 0) ? false : true;
       } else {
 	error(errSyntaxWarning, -1, "Bad annotation destination position");
 	return;
@@ -301,13 +300,13 @@ LinkDest::LinkDest(const Array *a) {
   } else if (obj1.isName("FitH")) {
     kind = destFitH;
     if (a->getLength() < 3) {
-      changeTop = gFalse;
+      changeTop = false;
     } else {
       Object obj2 = a->get(2);
       if (obj2.isNull()) {
-	changeTop = gFalse;
+	changeTop = false;
       } else if (obj2.isNum()) {
-	changeTop = gTrue;
+	changeTop = true;
 	top = obj2.getNum();
       } else {
 	error(errSyntaxWarning, -1, "Bad annotation destination position");
@@ -324,9 +323,9 @@ LinkDest::LinkDest(const Array *a) {
     kind = destFitV;
     Object obj2 = a->get(2);
     if (obj2.isNull()) {
-      changeLeft = gFalse;
+      changeLeft = false;
     } else if (obj2.isNum()) {
-      changeLeft = gTrue;
+      changeLeft = true;
       left = obj2.getNum();
     } else {
       error(errSyntaxWarning, -1, "Bad annotation destination position");
@@ -382,9 +381,9 @@ LinkDest::LinkDest(const Array *a) {
     kind = destFitBH;
     Object obj2 = a->get(2);
     if (obj2.isNull()) {
-      changeTop = gFalse;
+      changeTop = false;
     } else if (obj2.isNum()) {
-      changeTop = gTrue;
+      changeTop = true;
       top = obj2.getNum();
     } else {
       error(errSyntaxWarning, -1, "Bad annotation destination position");
@@ -400,9 +399,9 @@ LinkDest::LinkDest(const Array *a) {
     kind = destFitBV;
     Object obj2 = a->get(2);
     if (obj2.isNull()) {
-      changeLeft = gFalse;
+      changeLeft = false;
     } else if (obj2.isNum()) {
-      changeLeft = gTrue;
+      changeLeft = true;
       left = obj2.getNum();
     } else {
       error(errSyntaxWarning, -1, "Bad annotation destination position");
@@ -414,7 +413,7 @@ LinkDest::LinkDest(const Array *a) {
     error(errSyntaxWarning, -1, "Unknown annotation destination type");
   }
 
-  ok = gTrue;
+  ok = true;
   return;
 }
 
@@ -433,7 +432,7 @@ LinkDest::LinkDest(const LinkDest *dest) {
   changeLeft = dest->changeLeft;
   changeTop = dest->changeTop;
   changeZoom = dest->changeZoom;
-  ok = gTrue;
+  ok = true;
 }
 
 //------------------------------------------------------------------------
@@ -684,9 +683,9 @@ LinkMovie::~LinkMovie() {
 
 LinkSound::LinkSound(const Object *soundObj) {
   volume = 1.0;
-  sync = gFalse;
-  repeat = gFalse;
-  mix = gFalse;
+  sync = false;
+  repeat = false;
+  mix = false;
   sound = nullptr;
   if (soundObj->isDict())
   {
@@ -823,7 +822,7 @@ LinkJavaScript::~LinkJavaScript() {
 //------------------------------------------------------------------------
 LinkOCGState::LinkOCGState(const Object *obj) {
   stateList = new GooList();
-  preserveRB = gTrue;
+  preserveRB = true;
 
   Object obj1 = obj->dictLookup("State");
   if (obj1.isArray()) {
@@ -833,7 +832,7 @@ LinkOCGState::LinkOCGState(const Object *obj) {
       Object obj2 = obj1.arrayGetNF(i);
       if (obj2.isName()) {
         if (stList)
-	  stateList->append(stList);
+	  stateList->push_back(stList);
 
 	const char *name = obj2.getName();
 	stList = new StateList();
@@ -855,7 +854,7 @@ LinkOCGState::LinkOCGState(const Object *obj) {
 	  Ref *item = new Ref();
 	  item->num = ocgRef.num;
 	  item->gen = ocgRef.gen;
-	  stList->list->append(item);
+	  stList->list->push_back(item);
 	} else {
 	  error(errSyntaxWarning, -1, "Invalid OCG Action State array, expected name instead of ref");
 	}
@@ -865,7 +864,7 @@ LinkOCGState::LinkOCGState(const Object *obj) {
     }
     // Add the last group
     if (stList)
-      stateList->append(stList);
+      stateList->push_back(stList);
   } else {
     error(errSyntaxWarning, -1, "Invalid OCGState action");
     delete stateList;
@@ -880,12 +879,12 @@ LinkOCGState::LinkOCGState(const Object *obj) {
 
 LinkOCGState::~LinkOCGState() {
   if (stateList)
-    deleteGooList(stateList, StateList);
+    deleteGooList<StateList>(stateList);
 }
 
 LinkOCGState::StateList::~StateList() {
   if (list)
-    deleteGooList(list, Ref);
+    deleteGooList<Ref>(list);
 }
 
 //------------------------------------------------------------------------
@@ -974,12 +973,12 @@ LinkAction *Links::find(double x, double y) const {
   return nullptr;
 }
 
-GBool Links::onLink(double x, double y) const {
+bool Links::onLink(double x, double y) const {
   int i;
 
   for (i = 0; i < numLinks; ++i) {
     if (links[i]->inRect(x, y))
-      return gTrue;
+      return true;
   }
-  return gFalse;
+  return false;
 }
