@@ -14,10 +14,6 @@
 #ifndef OPTIONALCONTENT_H
 #define OPTIONALCONTENT_H
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
-
 #include "Object.h"
 #include "CharTypes.h"
 #include <unordered_map>
@@ -41,7 +37,7 @@ public:
   OCGs& operator=(const OCGs &) = delete;
 
   // Is OCGS valid?
-  GBool isOk() const { return ok; }
+  bool isOk() const { return ok; }
   
   bool hasOCGs() const;
   const std::unordered_map< Ref, std::unique_ptr< OptionalContentGroup > > &getOCGs() const { return optionalContentGroups; }
@@ -53,16 +49,16 @@ public:
   OCDisplayNode *getDisplayRoot();
 
   Array* getOrderArray() 
-    { return (order.isArray() && order.arrayGetLength() > 0) ? order.getArray() : NULL; }
+    { return (order.isArray() && order.arrayGetLength() > 0) ? order.getArray() : nullptr; }
   Array* getRBGroupsArray() 
-    { return (rbgroups.isArray() && rbgroups.arrayGetLength()) ? rbgroups.getArray() : NULL; }
+    { return (rbgroups.isArray() && rbgroups.arrayGetLength()) ? rbgroups.getArray() : nullptr; }
 
   bool optContentIsVisible( Object *dictRef );
 
 private:
-  GBool ok;
+  bool ok;
 
-  GBool evalOCVisibilityExpr(Object *expr, int recursion);
+  bool evalOCVisibilityExpr(Object *expr, int recursion);
   bool allOn( Array *ocgArray );
   bool allOff( Array *ocgArray );
   bool anyOn( Array *ocgArray );
@@ -142,9 +138,9 @@ private:
   void addChildren(GooList *childrenA);
   GooList *takeChildren();
 
-  GooString *name;		// display name (may be NULL)
-  OptionalContentGroup *ocg;	// NULL for display labels
-  GooList *children;		// NULL if there are no children
+  GooString *name;		// display name (may be nullptr)
+  OptionalContentGroup *ocg;	// nullptr for display labels
+  GooList *children;		// nullptr if there are no children
 				//   [OCDisplayNode]
 };
 
