@@ -25,7 +25,7 @@
 // Copyright (C) 2011, 2013, 2014, 2016 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2012 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
-// Copyright (C) 2013 Adam Reichold <adamreichold@myopera.com>
+// Copyright (C) 2013, 2018 Adam Reichold <adamreichold@myopera.com>
 // Copyright (C) 2013 Adrian Perez de Castro <aperez@igalia.com>
 // Copyright (C) 2015 André Guerreiro <aguerreiro1985@gmail.com>
 // Copyright (C) 2015 André Esser <bepandre@hotmail.com>
@@ -41,13 +41,10 @@
 #ifndef PDFDOC_H
 #define PDFDOC_H
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
+#include <mutex>
 
 #include "poppler-config.h"
 #include <stdio.h>
-#include "goo/GooMutex.h"
 #include "XRef.h"
 #include "Catalog.h"
 #include "Page.h"
@@ -117,54 +114,54 @@ enum PDFSubtypeConformance {
 class PDFDoc {
 public:
 
-  PDFDoc(GooString *fileNameA, GooString *ownerPassword = NULL,
-	 GooString *userPassword = NULL, void *guiDataA = NULL);
+  PDFDoc(const GooString *fileNameA, const GooString *ownerPassword = nullptr,
+	 const GooString *userPassword = nullptr, void *guiDataA = nullptr);
 
 #ifdef _WIN32
-  PDFDoc(wchar_t *fileNameA, int fileNameLen, GooString *ownerPassword = NULL,
-	 GooString *userPassword = NULL, void *guiDataA = NULL);
+  PDFDoc(wchar_t *fileNameA, int fileNameLen, GooString *ownerPassword = nullptr,
+	 GooString *userPassword = nullptr, void *guiDataA = nullptr);
 #endif
 
-  PDFDoc(BaseStream *strA, GooString *ownerPassword = NULL,
-	 GooString *userPassword = NULL, void *guiDataA = NULL);
+  PDFDoc(BaseStream *strA, const GooString *ownerPassword = nullptr,
+	 const GooString *userPassword = nullptr, void *guiDataA = nullptr);
   ~PDFDoc();
 
   PDFDoc(const PDFDoc &) = delete;
   PDFDoc& operator=(const PDFDoc &) = delete;
 
-  static PDFDoc *ErrorPDFDoc(int errorCode, GooString *fileNameA = NULL);
+  static PDFDoc *ErrorPDFDoc(int errorCode, const GooString *fileNameA = nullptr);
 
   // Was PDF document successfully opened?
-  GBool isOk() { return ok; }
+  bool isOk() const { return ok; }
 
   // Get the error code (if isOk() returns false).
-  int getErrorCode() { return errCode; }
+  int getErrorCode() const { return errCode; }
 
   // Get the error code returned by fopen() (if getErrorCode() == 
   // errOpenFile).
-  int getFopenErrno() { return fopenErrno; }
+  int getFopenErrno() const { return fopenErrno; }
 
   // Get file name.
-  GooString *getFileName() { return fileName; }
+  const GooString *getFileName() const { return fileName; }
 #ifdef _WIN32
   wchar_t *getFileNameU() { return fileNameU; }
 #endif
 
   // Get the linearization table.
   Linearization *getLinearization();
-  GBool checkLinearization();
+  bool checkLinearization();
 
   // Get the xref table.
-  XRef *getXRef() { return xref; }
+  XRef *getXRef() const { return xref; }
 
   // Get catalog.
-  Catalog *getCatalog() { return catalog; }
+  Catalog *getCatalog() const { return catalog; }
 
   // Get optional content configuration
-  OCGs *getOptContentConfig() { return catalog->getOptContentConfig(); }
+  OCGs *getOptContentConfig() const { return catalog->getOptContentConfig(); }
 
   // Get base stream.
-  BaseStream *getBaseStream() { return str; }
+  BaseStream *getBaseStream() const { return str; }
 
   // Get page parameters.
   double getPageMediaWidth(int page)
@@ -181,12 +178,12 @@ public:
   // Get number of pages.
   int getNumPages();
 
-  // Return the contents of the metadata stream, or NULL if there is
+  // Return the contents of the metadata stream, or nullptr if there is
   // no metadata.
-  GooString *readMetadata() { return catalog->readMetadata(); }
+  const GooString *readMetadata() const { return catalog->readMetadata(); }
 
   // Return the structure tree root object.
-  StructTreeRoot *getStructTreeRoot() { return catalog->getStructTreeRoot(); }
+  const StructTreeRoot *getStructTreeRoot() const { return catalog->getStructTreeRoot(); }
 
   // Get page.
   Page *getPage(int page);
@@ -194,30 +191,30 @@ public:
   // Display a page.
   void displayPage(OutputDev *out, int page,
 		   double hDPI, double vDPI, int rotate,
-		   GBool useMediaBox, GBool crop, GBool printing,
-		   GBool (*abortCheckCbk)(void *data) = NULL,
-		   void *abortCheckCbkData = NULL,
-                   GBool (*annotDisplayDecideCbk)(Annot *annot, void *user_data) = NULL,
-                   void *annotDisplayDecideCbkData = NULL, GBool copyXRef = gFalse);
+		   bool useMediaBox, bool crop, bool printing,
+		   bool (*abortCheckCbk)(void *data) = nullptr,
+		   void *abortCheckCbkData = nullptr,
+                   bool (*annotDisplayDecideCbk)(Annot *annot, void *user_data) = nullptr,
+                   void *annotDisplayDecideCbkData = nullptr, bool copyXRef = false);
 
   // Display a range of pages.
   void displayPages(OutputDev *out, int firstPage, int lastPage,
 		    double hDPI, double vDPI, int rotate,
-		    GBool useMediaBox, GBool crop, GBool printing,
-		    GBool (*abortCheckCbk)(void *data) = NULL,
-		    void *abortCheckCbkData = NULL,
-                    GBool (*annotDisplayDecideCbk)(Annot *annot, void *user_data) = NULL,
-                    void *annotDisplayDecideCbkData = NULL);
+		    bool useMediaBox, bool crop, bool printing,
+		    bool (*abortCheckCbk)(void *data) = nullptr,
+		    void *abortCheckCbkData = nullptr,
+                    bool (*annotDisplayDecideCbk)(Annot *annot, void *user_data) = nullptr,
+                    void *annotDisplayDecideCbkData = nullptr);
 
   // Display part of a page.
   void displayPageSlice(OutputDev *out, int page,
 			double hDPI, double vDPI, int rotate, 
-			GBool useMediaBox, GBool crop, GBool printing,
+			bool useMediaBox, bool crop, bool printing,
 			int sliceX, int sliceY, int sliceW, int sliceH,
-			GBool (*abortCheckCbk)(void *data) = NULL,
-			void *abortCheckCbkData = NULL,
-                        GBool (*annotDisplayDecideCbk)(Annot *annot, void *user_data) = NULL,
-                        void *annotDisplayDecideCbkData = NULL, GBool copyXRef = gFalse);
+			bool (*abortCheckCbk)(void *data) = nullptr,
+			void *abortCheckCbkData = nullptr,
+                        bool (*annotDisplayDecideCbk)(Annot *annot, void *user_data) = nullptr,
+                        void *annotDisplayDecideCbkData = nullptr, bool copyXRef = false);
 
   // Find a page, given its object ID.  Returns page number, or 0 if
   // not found.
@@ -228,45 +225,42 @@ public:
   Links *getLinks(int page);
 
   // Find a named destination.  Returns the link destination, or
-  // NULL if <name> is not a destination.
+  // nullptr if <name> is not a destination.
   LinkDest *findDest(const GooString *name)
     { return catalog->findDest(name); }
 
   // Process the links for a page.
   void processLinks(OutputDev *out, int page);
 
-
-#ifndef DISABLE_OUTLINE
   // Return the outline object.
   Outline *getOutline();
-#endif
 
   // Is the file encrypted?
-  GBool isEncrypted() { return xref->isEncrypted(); }
+  bool isEncrypted() { return xref->isEncrypted(); }
 
   std::vector<FormWidgetSignature*> getSignatureWidgets();
 
   // Check various permissions.
-  GBool okToPrint(GBool ignoreOwnerPW = gFalse)
+  bool okToPrint(bool ignoreOwnerPW = false)
     { return xref->okToPrint(ignoreOwnerPW); }
-  GBool okToPrintHighRes(GBool ignoreOwnerPW = gFalse)
+  bool okToPrintHighRes(bool ignoreOwnerPW = false)
     { return xref->okToPrintHighRes(ignoreOwnerPW); }
-  GBool okToChange(GBool ignoreOwnerPW = gFalse)
+  bool okToChange(bool ignoreOwnerPW = false)
     { return xref->okToChange(ignoreOwnerPW); }
-  GBool okToCopy(GBool ignoreOwnerPW = gFalse)
+  bool okToCopy(bool ignoreOwnerPW = false)
     { return xref->okToCopy(ignoreOwnerPW); }
-  GBool okToAddNotes(GBool ignoreOwnerPW = gFalse)
+  bool okToAddNotes(bool ignoreOwnerPW = false)
     { return xref->okToAddNotes(ignoreOwnerPW); }
-  GBool okToFillForm(GBool ignoreOwnerPW = gFalse)
+  bool okToFillForm(bool ignoreOwnerPW = false)
     { return xref->okToFillForm(ignoreOwnerPW); }
-  GBool okToAccessibility(GBool ignoreOwnerPW = gFalse)
+  bool okToAccessibility(bool ignoreOwnerPW = false)
     { return xref->okToAccessibility(ignoreOwnerPW); }
-  GBool okToAssemble(GBool ignoreOwnerPW = gFalse)
+  bool okToAssemble(bool ignoreOwnerPW = false)
     { return xref->okToAssemble(ignoreOwnerPW); }
 
 
   // Is this document linearized?
-  GBool isLinearized(GBool tryingToReconstruct = gFalse);
+  bool isLinearized(bool tryingToReconstruct = false);
 
   // Return the document's Info dictionary (if any).
   Object getDocInfo() { return xref->getDocInfo(); }
@@ -279,12 +273,12 @@ public:
   // Remove the document's Info dictionary and update the trailer dictionary.
   void removeDocInfo() { xref->removeDocInfo(); }
 
-  // Set doc info string entry. NULL or empty value will cause a removal.
+  // Set doc info string entry. nullptr or empty value will cause a removal.
   // Takes ownership of value.
   void setDocInfoStringEntry(const char *key, GooString *value);
 
   // Set document's properties in document's Info dictionary.
-  // NULL or empty value will cause a removal.
+  // nullptr or empty value will cause a removal.
   // Takes ownership of value.
   void setDocInfoTitle(GooString *title) { setDocInfoStringEntry("Title", title); }
   void setDocInfoAuthor(GooString *author) { setDocInfoStringEntry("Author", author); }
@@ -296,7 +290,7 @@ public:
   void setDocInfoModDate(GooString *modDate) { setDocInfoStringEntry("ModDate", modDate); }
 
   // Get document's properties from document's Info dictionary.
-  // Returns NULL on fail.
+  // Returns nullptr on fail.
   // Returned GooStrings should be freed by the caller.
   GooString *getDocInfoStringEntry(const char *key);
 
@@ -315,11 +309,11 @@ public:
   PDFSubtypeConformance getPDFSubtypeConformance() const { return pdfConformance; }
 
   // Return the PDF version specified by the file.
-  int getPDFMajorVersion() { return pdfMajorVersion; }
-  int getPDFMinorVersion() { return pdfMinorVersion; }
+  int getPDFMajorVersion() const { return pdfMajorVersion; }
+  int getPDFMinorVersion() const { return pdfMinorVersion; }
 
   //Return the PDF ID in the trailer dictionary (if any).
-  GBool getID(GooString *permanent_id, GooString *update_id);
+  bool getID(GooString *permanent_id, GooString *update_id) const;
 
   // Save one page with another name.
   int savePageAs(GooString *name, int pageNo);
@@ -336,19 +330,19 @@ public:
   void *getGUIData() { return guiData; }
 
   // rewrite pageDict with MediaBox, CropBox and new page CTM
-  void replacePageDict(int pageNo, int rotate, PDFRectangle *mediaBox, PDFRectangle *cropBox);
+  void replacePageDict(int pageNo, int rotate, const PDFRectangle *mediaBox, const PDFRectangle *cropBox);
   void markPageObjects(Dict *pageDict, XRef *xRef, XRef *countRef, Guint numOffset, int oldRefNum, int newRefNum, std::set<Dict*> *alreadyMarkedDicts = nullptr);
-  GBool markAnnotations(Object *annots, XRef *xRef, XRef *countRef, Guint numOffset, int oldPageNum, int newPageNum, std::set<Dict*> *alreadyMarkedDicts = nullptr);
+  bool markAnnotations(Object *annots, XRef *xRef, XRef *countRef, Guint numOffset, int oldPageNum, int newPageNum, std::set<Dict*> *alreadyMarkedDicts = nullptr);
   void markAcroForm(Object *acrpForm, XRef *xRef, XRef *countRef, Guint numOffset, int oldPageNum, int newPageNum);
   // write all objects used by pageDict to outStr
-  Guint writePageObjects(OutStream *outStr, XRef *xRef, Guint numOffset, GBool combine = gFalse);
+  Guint writePageObjects(OutStream *outStr, XRef *xRef, Guint numOffset, bool combine = false);
   static void writeObject (Object *obj, OutStream* outStr, XRef *xref, Guint numOffset, Guchar *fileKey,
                            CryptAlgorithm encAlgorithm, int keyLength, int objNum, int objGen, std::set<Dict*> *alreadyWrittenDicts = nullptr);
   static void writeHeader(OutStream *outStr, int major, int minor);
 
-  static Object createTrailerDict (int uxrefSize, GBool incrUpdate, Goffset startxRef,
+  static Object createTrailerDict (int uxrefSize, bool incrUpdate, Goffset startxRef,
                                   Ref *root, XRef *xRef, const char *fileName, Goffset fileSize);
-  static void writeXRefTableTrailer (Object &&trailerDict, XRef *uxref, GBool writeAllEntries,
+  static void writeXRefTableTrailer (Object &&trailerDict, XRef *uxref, bool writeAllEntries,
                                      Goffset uxrefOffset, OutStream* outStr, XRef *xRef);
   static void writeXRefStreamTrailer (Object &&trailerDict, XRef *uxref, Ref *uxrefStreamRef,
                                       Goffset uxrefOffset, OutStream* outStr, XRef *xRef);
@@ -369,9 +363,9 @@ private:
   { writeObject(obj, outStr, getXRef(), 0, fileKey, encAlgorithm, keyLength, objNum, objGen, alreadyWrittenDicts); }
   static void writeStream (Stream* str, OutStream* outStr);
   static void writeRawStream (Stream* str, OutStream* outStr);
-  void writeXRefTableTrailer (Goffset uxrefOffset, XRef *uxref, GBool writeAllEntries,
-                              int uxrefSize, OutStream* outStr, GBool incrUpdate);
-  static void writeString (const GooString* s, OutStream* outStr, Guchar *fileKey,
+  void writeXRefTableTrailer (Goffset uxrefOffset, XRef *uxref, bool writeAllEntries,
+                              int uxrefSize, OutStream* outStr, bool incrUpdate);
+  static void writeString (const GooString* s, OutStream* outStr, const Guchar *fileKey,
                            CryptAlgorithm encAlgorithm, int keyLength, int objNum, int objGen);
   void saveIncrementalUpdate (OutStream* outStr);
   void saveCompleteRewrite (OutStream* outStr);
@@ -383,23 +377,23 @@ private:
 
   PDFDoc();
   void init();
-  GBool setup(GooString *ownerPassword, GooString *userPassword);
-  GBool checkFooter();
+  bool setup(const GooString *ownerPassword, const GooString *userPassword);
+  bool checkFooter();
   void checkHeader();
-  GBool checkEncryption(GooString *ownerPassword, GooString *userPassword);
+  bool checkEncryption(const GooString *ownerPassword, const GooString *userPassword);
   void extractPDFSubtype();
 
   // Get the offset of the start xref table.
-  Goffset getStartXRef(GBool tryingToReconstruct = gFalse);
+  Goffset getStartXRef(bool tryingToReconstruct = false);
   // Get the offset of the entries in the main XRef table of a
   // linearized document (0 for non linearized documents).
-  Goffset getMainXRefEntriesOffset(GBool tryingToReconstruct = gFalse);
-  long long strToLongLong(char *s);
+  Goffset getMainXRefEntriesOffset(bool tryingToReconstruct = false);
+  long long strToLongLong(const char *s);
 
   // Mark the document's Info dictionary as modified.
   void setDocInfoModified(Object *infoObj);
 
-  GooString *fileName;
+  const GooString *fileName;
 #ifdef _WIN32
   wchar_t *fileNameU;
 #endif
@@ -420,21 +414,17 @@ private:
   SecurityHandler *secHdlr;
   Catalog *catalog;
   Hints *hints;
-#ifndef DISABLE_OUTLINE
   Outline *outline;
-#endif
   Page **pageCache;
 
-  GBool ok;
+  bool ok;
   int errCode;
   //If there is an error opening the PDF file with fopen() in the constructor, 
   //then the POSIX errno will be here.
   int fopenErrno;
 
   Goffset startXRefPos;		// offset of last xref table
-#ifdef MULTITHREADED
-  GooMutex mutex;
-#endif
+  mutable std::recursive_mutex mutex;
 };
 
 #endif
