@@ -13,17 +13,18 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005, 2007, 2011 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007, 2011, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006 Rainer Keller <class321@gmx.de>
 // Copyright (C) 2008 Timothy Lee <timothy.lee@siriushk.com>
 // Copyright (C) 2008 Vasile Gaburici <gaburici@cs.umd.edu>
 // Copyright (C) 2009 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2009 William Bader <williambader@hotmail.com>
 // Copyright (C) 2010 Jakob Voss <jakob.voss@gbv.de>
-// Copyright (C) 2012, 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2012, 2013, 2017, 2018 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2013 Thomas Fischer <fischer@unix-ag.uni-kl.de>
 // Copyright (C) 2013 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2017 Caolán McNamara <caolanm@redhat.com>
+// Copyright (C) 2018 Andreas Gruenbacher <agruenba@redhat.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -33,10 +34,6 @@
 #include "config.h"
 #include <poppler-config.h>
 
-#ifdef USE_GCC_PRAGMAS
-#pragma implementation
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <stddef.h>
@@ -53,22 +50,22 @@
 #include "JBIG2Stream.h"
 #include "ImageOutputDev.h"
 
-ImageOutputDev::ImageOutputDev(char *fileRootA, GBool pageNamesA, GBool listImagesA) {
+ImageOutputDev::ImageOutputDev(char *fileRootA, bool pageNamesA, bool listImagesA) {
   listImages = listImagesA;
   if (!listImages) {
     fileRoot = copyString(fileRootA);
     fileName = (char *)gmalloc(strlen(fileRoot) + 45);
   }
-  outputPNG = gFalse;
-  outputTiff = gFalse;
-  dumpJPEG =  gFalse;
-  dumpJP2 = gFalse;
-  dumpJBIG2 = gFalse;
-  dumpCCITT = gFalse;
+  outputPNG = false;
+  outputTiff = false;
+  dumpJPEG =  false;
+  dumpJP2 = false;
+  dumpJBIG2 = false;
+  dumpCCITT = false;
   pageNames = pageNamesA;
   imgNum = 0;
   pageNum = 0;
-  ok = gTrue;
+  ok = true;
   if (listImages) {
     printf("page   num  type   width height color comp bpc  enc interp  object ID x-ppi y-ppi size ratio\n");
     printf("--------------------------------------------------------------------------------------------\n");
@@ -122,7 +119,7 @@ static void printNumber(double d)
 void ImageOutputDev::listImage(GfxState *state, Object *ref, Stream *str,
 			       int width, int height,
 			       GfxImageColorMap *colorMap,
-			       GBool interpolate, GBool inlineImg,
+			       bool interpolate, bool inlineImg,
 			       ImageType imageType) {
   const char *type;
   const char *colorspace;
@@ -231,7 +228,7 @@ void ImageOutputDev::listImage(GfxState *state, Object *ref, Stream *str,
     printf("[none]     ");
   }
 
-  double *mat = state->getCTM();
+  const double *mat = state->getCTM();
   double width2 = mat[0] + mat[2];
   double height2 = mat[1] + mat[3];
   double xppi = fabs(width*72.0/width2) + 0.5;
@@ -292,25 +289,6 @@ void ImageOutputDev::listImage(GfxState *state, Object *ref, Stream *str,
 
   ++imgNum;
 
-  if (inlineImg) {
-    // For inline images we need to advance the stream position to the end of the image
-    // as Gfx needs to continue reading content after the image data.
-    ImageFormat format;
-    if (!colorMap || (colorMap->getNumPixelComps() == 1 && colorMap->getBits() == 1)) {
-      format = imgMonochrome;
-    } else if (colorMap->getColorSpace()->getMode() == csDeviceGray ||
-               colorMap->getColorSpace()->getMode() == csCalGray) {
-      format = imgGray;
-    } else if ((colorMap->getColorSpace()->getMode() == csDeviceRGB ||
-		colorMap->getColorSpace()->getMode() == csCalRGB ||
-		(colorMap->getColorSpace()->getMode() == csICCBased && colorMap->getNumPixelComps() == 3)) &&
-	       colorMap->getBits() > 8) {
-      format = imgRGB48;
-    } else {
-      format = imgRGB;
-    }
-    writeImageFile(NULL, format, "", str, width, height, colorMap);
-  }
 }
 
 long ImageOutputDev::getInlineImageLength(Stream *str, int width, int height,
@@ -337,16 +315,12 @@ long ImageOutputDev::getInlineImageLength(Stream *str, int width, int height,
 
   EmbedStream *embedStr = (EmbedStream *) (str->getBaseStream());
   embedStr->rewind();
-  if (str->getKind() == strDCT || str->getKind() == strCCITTFax)
-    str = str->getNextStream();
   len = 0;
-  str->reset();
-  while (str->getChar() != EOF)
+  while (embedStr->getChar() != EOF)
     len++;
 
   embedStr->restore();
 
-
   return len;
 }
 
@@ -377,7 +351,7 @@ void ImageOutputDev::writeRawImage(Stream *str, const char *ext) {
 void ImageOutputDev::writeImageFile(ImgWriter *writer, ImageFormat format, const char *ext,
                                     Stream *str, int width, int height, GfxImageColorMap *colorMap) {
   FILE *f = nullptr; /* squelch bogus compiler warning */
-  ImageStream *imgStr = NULL;
+  ImageStream *imgStr = nullptr;
   unsigned char *row;
   unsigned char *rowp;
   Guchar *p;
@@ -535,23 +509,22 @@ void ImageOutputDev::writeImageFile(ImgWriter *writer, ImageFormat format, const
 
 void ImageOutputDev::writeImage(GfxState *state, Object *ref, Stream *str,
 				int width, int height,
-				GfxImageColorMap *colorMap, GBool inlineImg) {
+				GfxImageColorMap *colorMap, bool inlineImg) {
   ImageFormat format;
   EmbedStream *embedStr;
 
-  if (dumpJPEG && str->getKind() == strDCT) {
-    if (inlineImg) {
+  if (inlineImg) {
       embedStr = (EmbedStream *) (str->getBaseStream());
-      getInlineImageLength(str, width, height, colorMap); // record the strean
+      // Record the stream. This determines the size.
+      getInlineImageLength(str, width, height, colorMap);
+      // Reading the stream again will return EOF at end of recording.
       embedStr->rewind();
-    }
+  }
 
+  if (dumpJPEG && str->getKind() == strDCT) {
     // dump JPEG file
     writeRawImage(str, "jpg");
 
-    if (inlineImg)
-      embedStr->restore();
-
   } else if (dumpJP2 && str->getKind() == strJPX && !inlineImg) {
     // dump JPEG2000 file
     writeRawImage(str, "jp2");
@@ -563,17 +536,17 @@ void ImageOutputDev::writeImage(GfxState *state, Object *ref, Stream *str,
     if (globals->isStream()) {
       FILE *f;
       int c;
-      Stream *str = globals->getStream();
+      Stream *globalsStr = globals->getStream();
 
       setFilename("jb2g");
       if (!(f = fopen(fileName, "wb"))) {
         error(errIO, -1, "Couldn't open image file '{0:s}'", fileName);
         return;
       }
-      str->reset();
-      while ((c = str->getChar()) != EOF)
+      globalsStr->reset();
+      while ((c = globalsStr->getChar()) != EOF)
         fputc(c, f);
-      str->close();
+      globalsStr->close();
       fclose(f);
     }
 
@@ -612,18 +585,9 @@ void ImageOutputDev::writeImage(GfxState *state, Object *ref, Stream *str,
 
     fclose(f);
 
-    if (inlineImg) {
-      embedStr = (EmbedStream *) (str->getBaseStream());
-      getInlineImageLength(str, width, height, colorMap); // record the strean
-      embedStr->rewind();
-    }
-
     // dump CCITT file
     writeRawImage(str, "ccitt");
 
-    if (inlineImg)
-      embedStr->restore();
-
   } else if (outputPNG && !(outputTiff && colorMap &&
                             (colorMap->getColorSpace()->getMode() == csDeviceCMYK ||
                              (colorMap->getColorSpace()->getMode() == csICCBased &&
@@ -652,8 +616,9 @@ void ImageOutputDev::writeImage(GfxState *state, Object *ref, Stream *str,
     }
 
     writeImageFile(writer, format, "png", str, width, height, colorMap);
-#endif
 
+    delete writer;
+#endif
   } else if (outputTiff) {
     // output in TIFF format
 
@@ -683,8 +648,9 @@ void ImageOutputDev::writeImage(GfxState *state, Object *ref, Stream *str,
     }
 
     writeImageFile(writer, format, "tif", str, width, height, colorMap);
-#endif
 
+    delete writer;
+#endif
   } else {
     // output in PPM/PBM format
     ImgWriter *writer;
@@ -703,30 +669,33 @@ void ImageOutputDev::writeImage(GfxState *state, Object *ref, Stream *str,
 
     delete writer;
   }
+
+  if (inlineImg)
+      embedStr->restore();
 }
 
-GBool ImageOutputDev::tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat, Object *str,
-				  double *pmat, int paintType, int tilingType, Dict *resDict,
-				  double *mat, double *bbox,
+bool ImageOutputDev::tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat, Object *str,
+				  const double *pmat, int paintType, int tilingType, Dict *resDict,
+				  const double *mat, const double *bbox,
 				  int x0, int y0, int x1, int y1,
 				  double xStep, double yStep) {
-  return gTrue;
+  return true;
   // do nothing -- this avoids the potentially slow loop in Gfx.cc
 }
 
 void ImageOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str,
-				   int width, int height, GBool invert,
-				   GBool interpolate, GBool inlineImg) {
+				   int width, int height, bool invert,
+				   bool interpolate, bool inlineImg) {
   if (listImages)
-    listImage(state, ref, str, width, height, NULL, interpolate, inlineImg, imgStencil);
+    listImage(state, ref, str, width, height, nullptr, interpolate, inlineImg, imgStencil);
   else
-    writeImage(state, ref, str, width, height, NULL, inlineImg);
+    writeImage(state, ref, str, width, height, nullptr, inlineImg);
 }
 
 void ImageOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
 			       int width, int height,
 			       GfxImageColorMap *colorMap,
-			       GBool interpolate, int *maskColors, GBool inlineImg) {
+			       bool interpolate, int *maskColors, bool inlineImg) {
   if (listImages)
     listImage(state, ref, str, width, height, colorMap, interpolate, inlineImg, imgImage);
   else
@@ -735,27 +704,27 @@ void ImageOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
 
 void ImageOutputDev::drawMaskedImage(
   GfxState *state, Object *ref, Stream *str,
-  int width, int height, GfxImageColorMap *colorMap, GBool interpolate,
-  Stream *maskStr, int maskWidth, int maskHeight, GBool maskInvert, GBool maskInterpolate) {
+  int width, int height, GfxImageColorMap *colorMap, bool interpolate,
+  Stream *maskStr, int maskWidth, int maskHeight, bool maskInvert, bool maskInterpolate) {
   if (listImages) {
-    listImage(state, ref, str, width, height, colorMap, interpolate, gFalse, imgImage);
-    listImage(state, ref, str, maskWidth, maskHeight, NULL, maskInterpolate, gFalse, imgMask);
+    listImage(state, ref, str, width, height, colorMap, interpolate, false, imgImage);
+    listImage(state, ref, str, maskWidth, maskHeight, nullptr, maskInterpolate, false, imgMask);
   } else {
-    writeImage(state, ref, str, width, height, colorMap, gFalse);
-    writeImage(state, ref, maskStr, maskWidth, maskHeight, NULL, gFalse);
+    writeImage(state, ref, str, width, height, colorMap, false);
+    writeImage(state, ref, maskStr, maskWidth, maskHeight, nullptr, false);
   }
 }
 
 void ImageOutputDev::drawSoftMaskedImage(
   GfxState *state, Object *ref, Stream *str,
-  int width, int height, GfxImageColorMap *colorMap, GBool interpolate,
+  int width, int height, GfxImageColorMap *colorMap, bool interpolate,
   Stream *maskStr, int maskWidth, int maskHeight,
-  GfxImageColorMap *maskColorMap, GBool maskInterpolate) {
+  GfxImageColorMap *maskColorMap, bool maskInterpolate) {
   if (listImages) {
-    listImage(state, ref, str, width, height, colorMap, interpolate, gFalse, imgImage);
-    listImage(state, ref, maskStr, maskWidth, maskHeight, maskColorMap, maskInterpolate, gFalse, imgSmask);
+    listImage(state, ref, str, width, height, colorMap, interpolate, false, imgImage);
+    listImage(state, ref, maskStr, maskWidth, maskHeight, maskColorMap, maskInterpolate, false, imgSmask);
   } else {
-    writeImage(state, ref, str, width, height, colorMap, gFalse);
-    writeImage(state, ref, maskStr, maskWidth, maskHeight, maskColorMap, gFalse);
+    writeImage(state, ref, str, width, height, colorMap, false);
+    writeImage(state, ref, maskStr, maskWidth, maskHeight, maskColorMap, false);
   }
 }
